<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-sites?lang_cible=de
// ** ne pas modifier le fichier **

return [

	// S
	'sites_description' => 'Verwaltung verlinkter und syndizierter Websites mit  SPIP (im öffentlichen und Redaktionsbereich)',
	'sites_slogan' => 'Verwaltung verlinkter und syndizierter Websites mit  SPIP',
];
